package org.eclipse.ui;

/*
 * (c) Copyright IBM Corp. 2000, 2001.
 * All Rights Reserved.
 */

/**
 * An adapter which performs action filtering.
 * <p>
 * Within the workbench a plugin may extend the actions which appear in the
 * context menu for any object.  The visibility of each action extension is controlled
 * by action filtering.  By default, the workbench will filter each action extension using 
 * the <code>objectClass</code> and optional <code>nameFilter</code> attributes defined
 * in xml.  If the action extension passes this test the action will be added to the 
 * context menu for the object. 
 * </p>
 * <p>
 * In some situations the object class and name are not enough to describe the intended
 * target action.  In those situations an action extension may define one or more 
 * <code>filter</code> sub-elements.  Each one of these elements describes one attribute of 
 * the action target using a <code>name value</code> pair.  The attributes for an object 
 * are type specific and beyond the domain of the workbench itself, so the workbench 
 * will delegate filtering at this level to an <code>IActionFilter</code>.  This is a 
 * filtering strategy which is provided by the selection itself and may perform type 
 * specific filtering.
 * </p>
 * <p>
 * The workbench will retrieve the filter from the selected object by testing to see
 * if it implements <code>IActionFilter</code>.  If that fails, the workbench will ask for
 * a filter through through the <code>IAdaptable</code> mechanism.  If a filter is
 * found the workbench will pass each name value pair to the filter to determine if it 
 * matches the state of the selected object.  If so, or there is no filter, the action 
 * will be added to the context menu for the object. 
 * </p>
 * <p>
 * The attribute names for <code>IResource, IMarker and IProject</code> are defined
 * in <code>IResourceActionFilter, IMarkerActionFilter, and IProjectActionFilter</code>.
 * </p>
 *
 * @see IAdaptable
 * @see IResourceActionFilter
 * @see IMarkerActionFilter
 * @see IProjectActionFilter
 */
public interface IActionFilter {
/**
 * Returns whether the specific attribute matches the state of the target
 * object.
 *
 * @param target the target object
 * @param name the attribute name
 * @param value the attriute value
 * @return <code>true</code> if the attribute matches; <code>false</code> otherwise
 */
public boolean testAttribute(Object target, String name, String value);
}
